Building tuples and lists
=========================

.. autocmodule:: autogen/public_api.h
   :members: HPyTupleBuilder_New,HPyTupleBuilder_Set,HPyTupleBuilder_Build,HPyTupleBuilder_Cancel

.. autocmodule:: autogen/public_api.h
   :members: HPyListBuilder_New,HPyListBuilder_Set,HPyListBuilder_Build,HPyListBuilder_Cancel
